==> snapd_2.51.1+20.10.tar.xz: snapd-2.51.1/daemon/export_access_test.go <==
// -*- Mode: Go; indent-tabs-mode: t -*-

/*
 * Copyright (C) 2021 Canonical Ltd
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

package daemon

import (
	"net/http"

	"github.com/snapcore/snapd/polkit"
)

type (
	AccessChecker = accessChecker
	AccessResult  = accessResult

	OpenAccess          = openAccess
	AuthenticatedAccess = authenticatedAccess
	RootAccess          = rootAccess
	SnapAccess          = snapAccess
)

const (
	AccessOK           = accessOK
	AccessUnauthorized = accessUnauthorized
	AccessForbidden    = accessForbidden
	AccessCancelled    = accessCancelled
)

var CheckPolkitActionImpl = checkPolkitActionImpl

func MockCheckPolkitAction(new func(r *http.Request, ucred *Ucrednet, action string) AccessResult) (restore func()) {
	old := checkPolkitAction
	checkPolkitAction = new
	return func() {
		checkPolkitAction = old
	}
}

func MockPolkitCheckAuthorization(new func(pid int32, uid uint32, actionId string, details map[string]string, flags polkit.CheckFlags) (bool, error)) (restore func()) {
	old := polkitCheckAuthorization
	polkitCheckAuthorization = new
	return func() {
		polkitCheckAuthorization = old
	}
}

==> snapd_2.58+22.10.1.tar.xz: snapd-2.58+22.10.1/daemon/export_access_test.go <==
// -*- Mode: Go; indent-tabs-mode: t -*-

/*
 * Copyright (C) 2021 Canonical Ltd
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

package daemon

import (
	"net/http"

	"github.com/snapcore/snapd/polkit"
)

type (
	AccessChecker = accessChecker

	OpenAccess                = openAccess
	AuthenticatedAccess       = authenticatedAccess
	RootAccess                = rootAccess
	SnapAccess                = snapAccess
	ThemesOpenAccess          = themesOpenAccess
	ThemesAuthenticatedAccess = themesAuthenticatedAccess
)

var CheckPolkitActionImpl = checkPolkitActionImpl

func MockCheckPolkitAction(new func(r *http.Request, ucred *Ucrednet, action string) *APIError) (restore func()) {
	old := checkPolkitAction
	checkPolkitAction = new
	return func() {
		checkPolkitAction = old
	}
}

func MockPolkitCheckAuthorization(new func(pid int32, uid uint32, actionId string, details map[string]string, flags polkit.CheckFlags) (bool, error)) (restore func()) {
	old := polkitCheckAuthorization
	polkitCheckAuthorization = new
	return func() {
		polkitCheckAuthorization = old
	}
}

func MockCgroupSnapNameFromPid(new func(pid int) (string, error)) (restore func()) {
	old := cgroupSnapNameFromPid
	cgroupSnapNameFromPid = new
	return func() {
		cgroupSnapNameFromPid = old
	}
}

var RequireThemeApiAccessImpl = requireThemeApiAccessImpl

func MockRequireThemeApiAccess(new func(d *Daemon, ucred *ucrednet) *apiError) (restore func()) {
	old := requireThemeApiAccess
	requireThemeApiAccess = new
	return func() {
		requireThemeApiAccess = old
	}
}
